QWED Test Report - 2025-12-02

# 🛡️ QWED Comprehensive Test Audit

Generated: 2025-12-02 02:32:02

CRITICAL ISSUES
Total Tests
9
Passed
0
Failed
9
Pass Rate
0.0%
Duration
0.0s

## 📊 Results by Priority

Priority | Total | Passed | Failed | Pass Rate
--- | --- | --- | --- | ---
CRITICAL | 4 | 0 | 4 | 0.0%
HIGH | 3 | 0 | 3 | 0.0%
MEDIUM | 2 | 0 | 2 | 0.0%

## 🔧 Results by Engine

Engine | Total | Passed | Failed | Pass Rate
--- | --- | --- | --- | ---
LOGIC | 9 | 0 | 9 | 0.0%

## ❌ Failed Tests (9)

### Verify simple SAT constraints

Engine: logic Priority: CRITICAL ID: LOGIC_SAT_001
'QWEDAPIClient' object has no attribute 'verify_logic'

### Detect simple contradiction (UNSAT)

Engine: logic Priority: CRITICAL ID: LOGIC_UNSAT_001
'QWEDAPIClient' object has no attribute 'verify_logic'

### Verify boolean logic constraints

Engine: logic Priority: CRITICAL ID: LOGIC_SAT_002
'QWEDAPIClient' object has no attribute 'verify_logic'

### Verify inequality chain (x < y < z)

Engine: logic Priority: HIGH ID: LOGIC_SAT_003
'QWEDAPIClient' object has no attribute 'verify_logic'

### Verify divisibility constraint (x % 5 == 0)

Engine: logic Priority: MEDIUM ID: LOGIC_SAT_004
'QWEDAPIClient' object has no attribute 'verify_logic'

### Verify implication (P implies Q)

Engine: logic Priority: MEDIUM ID: LOGIC_SAT_005
'QWEDAPIClient' object has no attribute 'verify_logic'

### Detect circular dependency (x=y+1 AND y=x+1)

Engine: logic Priority: HIGH ID: LOGIC_UNSAT_002
'QWEDAPIClient' object has no attribute 'verify_logic'

### Detect boolean contradiction (P AND NOT P)

Engine: logic Priority: CRITICAL ID: LOGIC_UNSAT_003
'QWEDAPIClient' object has no attribute 'verify_logic'

### Detect conflict in multiple constraints

Engine: logic Priority: HIGH ID: LOGIC_UNSAT_004
'QWEDAPIClient' object has no attribute 'verify_logic'